@@ -154,18 +154,31 @@ def _each_run_file_rotate_handler(in_file_name, in_back_up):
 
 def _stdout_handler():
     _date_format = DATEFORMAT_DEV
-    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}| {name:<50}|{funcName:^35}||--> {message}', datefmt=_date_format, style='{')
+    formatter = CustomFormatter(fmt='{asctime} |{levelname:^11}| {name:<50} |{funcName:^30}||--> {message}', datefmt=_date_format, style='{')
     # formatter = logging.Formatter(fmt='[{asctime}][{levelname:^7}][{name:<30}][{funcName:^25}] --> {message}', datefmt=_date_format, style='{')
     handler = logging.StreamHandler()
     handler.setFormatter(formatter)
     return handler
 
 
-def main_logger(in_file_name, in_level='DEBUG', in_back_up=2, other_logger_names=None, log_to='both'):
+def _minimal_stdout_handler():
+    _date_format = DATEFORMAT_DEV
+    formatter = CustomFormatter(fmt='{asctime} ||--> {message}', datefmt=_date_format, style='{')
+    # formatter = logging.Formatter(fmt='[{asctime}][{levelname:^7}][{name:<30}][{funcName:^25}] --> {message}', datefmt=_date_format, style='{')
+    handler = logging.StreamHandler()
+    handler.setFormatter(formatter)
+    return handler
+
+
+def main_logger(in_file_name, in_level='DEBUG', in_back_up=2, other_logger_names=None, log_to='both', stdout_formatter: str = None):
+    stdout_fomatter_map = {'minimal': _minimal_stdout_handler,
+                           'normal': _stdout_handler}
+    stdout_formatter = 'minimal' if stdout_formatter is None else stdout_formatter.casefold()
+    stdout_handler_function = stdout_fomatter_map.get(stdout_formatter, _minimal_stdout_handler)
     log_to = log_to.casefold()
     should_roll_over = os.path.isfile(in_file_name)
     run_rotating_file_handler = _each_run_file_rotate_handler(in_file_name=in_file_name, in_back_up=in_back_up)
-    stdout_handler = _stdout_handler()
+    stdout_handler = stdout_handler_function()
     _out = logging.getLogger('main')
     all_loggers = [_out] + list(map(logging.getLogger, other_logger_names)) if other_logger_names is not None else [_out]
     for logger in all_loggers:
